@@ -80,11 +80,6 @@ impl<W: WriteJs> WriteJs for OmitTrailingSemi<W> {
         self.inner.write_punct(span, s)
     }
 
-    #[inline]
-    fn target(&self) -> swc_ecma_ast::EsVersion {
-        self.inner.target()
-    }
-
     #[inline]
     fn care_about_srcmap(&self) -> bool {
         self.inner.care_about_srcmap()
